@@ -11,7 +11,7 @@ use Rose::DB::Object::Constants
   qw(PRIVATE_PREFIX FLAG_DB_IS_PRIVATE STATE_IN_DB STATE_LOADING
      STATE_SAVING);
 
-our $VERSION = '0.031';
+our $VERSION = '0.04';
 
 sub date
 {
@@ -21,14 +21,13 @@ sub date
   my $interface = $args->{'interface'} || 'get_set';
   my $tz = $args->{'time_zone'} || 0;
 
+  my $formatted_key = PRIVATE_PREFIX . "_${key}_formatted";
+  my $default = $args->{'default'};
+
   my %methods;
 
   if($interface eq 'get_set')
   {
-    my $formatted_key = PRIVATE_PREFIX . "_${key}_formatted";
-
-    my $default = $args->{'default'};
-
     $methods{$name} = sub
     {
       my $self = shift;
@@ -65,6 +64,10 @@ sub date
             return $dt  unless(ref $dt);
             return $db->format_date($dt->clone->truncate(to => $_[1]));
           }
+          else
+          {
+            Carp::croak "Invalid argument(s) to $name: @_";
+          }
         }
 
         if(defined $_[0])
@@ -97,6 +100,167 @@ sub date
             }
           }
         }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = undef;
+        }
+      }
+
+      return  unless(defined wantarray);
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->parse_date($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone) or
+            Carp::croak "Invalid default date: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->format_date($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->parse_date($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'get')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      if(@_ == 2)
+      {
+        my $dt = $self->{$key} || $self->{$formatted_key};
+
+        if(defined $dt && !ref $dt)
+        {
+          my $dt2 = $db->parse_date($dt);
+
+          unless($dt2)
+          {
+            $dt2 = Rose::DateTime::Util::parse_date($dt, $tz || $db->server_time_zone) or
+              Carp::croak "Could not parse date '$dt'";
+          }
+
+          $dt = $dt2;
+        }
+
+        if($_[0] eq 'format')
+        {
+          return $dt  unless(ref $dt);
+          return Rose::DateTime::Util::format_date($dt, (ref $_[1] ? @{$_[1]} : $_[1]));
+        }
+        elsif($_[0] eq 'truncate')
+        {
+          return undef  unless($self->{$key});
+          return $dt  unless(ref $dt);
+          return $db->format_date($dt->clone->truncate(to => $_[1]));
+        }
+        else
+        {
+          Carp::croak "Invalid argument(s) to $name: @_";
+        }
+      }
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->parse_date($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone) or
+            Carp::croak "Invalid default date: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->format_date($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->parse_date($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'set')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      Carp::croak "Missing argument in call to $name"  unless(@_);
+
+      if(defined $_[0])
+      {
+        if($self->{STATE_LOADING()})
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $_[0];
+        }
+        else
+        {
+          my $dt = $db->parse_date($_[0]);
+
+          unless($dt)
+          {
+            $dt = Rose::DateTime::Util::parse_date($_[0], $tz || $db->server_time_zone) or
+              Carp::croak "Invalid date: '$_[0]'";
+          }
+
+          if(ref $dt)
+          {
+            $dt->set_time_zone($tz || $db->server_time_zone);
+            $self->{$key} = $dt;
+            $self->{$formatted_key} = undef;
+          }
+          else
+          {
+            $self->{$key} = undef;
+            $self->{$formatted_key} = $dt;
+          }
+        }
+      }
+      else
+      {
+        $self->{$key} = undef;
+        $self->{$formatted_key} = undef;
       }
 
       return  unless(defined wantarray);
@@ -158,13 +322,13 @@ sub datetime
   my $format_method = "format_$type";
   my $parse_method  = "parse_$type";
 
-  my %methods;
+  my $formatted_key = PRIVATE_PREFIX . "_${name}_formatted";
+  my $default = $args->{'default'};
 
+  my %methods;
+ 
   if($interface eq 'get_set')
   {
-    my $formatted_key = PRIVATE_PREFIX . "_${name}_formatted";
-    my $default = $args->{'default'};
-
     $methods{$name} = sub
     {
       my $self = shift;
@@ -225,6 +389,125 @@ sub datetime
             $self->{$formatted_key} = undef;
           }
         }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = undef;
+        }
+      }
+
+      return  unless(defined wantarray);
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->$parse_method($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone) or
+            Carp::croak "Invalid default datetime: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->$format_method($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->$parse_method($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'get')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->$parse_method($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone) or
+            Carp::croak "Invalid default datetime: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->$format_method($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->$parse_method($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'set')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      Carp::croak "Missing argument in call to $name"  unless(@_);
+
+      if(defined $_[0])
+      {
+        if($self->{STATE_LOADING()})
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $_[0];
+        }
+        else
+        {
+          my $dt = $db->$parse_method($_[0]);
+
+          unless($dt)
+          {
+            $dt = Rose::DateTime::Util::parse_date($_[0], $tz || $db->server_time_zone) or
+              Carp::croak "Invalid datetime: '$_[0]'";
+          }
+
+          $dt->set_time_zone($tz || $db->server_time_zone)  if(ref $dt);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+      }
+      else
+      {
+        $self->{$key} = undef;
+        $self->{$formatted_key} = undef;
       }
 
       return  unless(defined wantarray);
@@ -289,13 +572,13 @@ sub timestamp
   my $interface = $args->{'interface'} || 'get_set';
   my $tz = $args->{'time_zone'} || 0;
 
+  my $formatted_key = PRIVATE_PREFIX . "_${name}_formatted";
+  my $default = $args->{'default'};
+
   my %methods;
 
   if($interface eq 'get_set')
   {
-    my $formatted_key = PRIVATE_PREFIX . "_${name}_formatted";
-    my $default = $args->{'default'};
-
     $methods{$name} = sub
     {
       my $self = shift;
@@ -332,6 +615,10 @@ sub timestamp
             return $db->format_timestamp($dt)  unless(ref $dt);
             return $dt->clone->truncate(to => $_[1]);
           }
+          else
+          {
+            Carp::croak "Invalid argument(s) to $name: @_";
+          }
         }
 
         if(defined $_[0])
@@ -356,6 +643,159 @@ sub timestamp
             $self->{$formatted_key} = undef;
           }
         }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = undef;
+        }
+      }
+
+      return  unless(defined wantarray);
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->parse_timestamp($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone, 1) or
+            Carp::croak "Invalid default timestamp: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->format_timestamp($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->parse_timestamp($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'get')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      if(@_ == 2)
+      {
+        my $dt = $self->{$key} || $self->{$formatted_key};
+
+        if(defined $dt && !ref $dt)
+        {
+          my $dt2 = $db->parse_timestamp($dt);
+
+          unless($dt2)
+          {
+            $dt2 = Rose::DateTime::Util::parse_date($dt, $tz || $db->server_time_zone, 1) or
+              Carp::croak "Could not parse timestamp '$dt'";
+          }
+
+          $dt = $dt2;
+        }
+
+        if($_[0] eq 'format')
+        {
+          return $dt  unless(ref $dt);
+          return Rose::DateTime::Util::format_date($dt, (ref $_[1] ? @{$_[1]} : $_[1]), 1);
+        }
+        elsif($_[0] eq 'truncate')
+        {
+          return undef  unless($self->{$key});
+          return $db->format_timestamp($dt)  unless(ref $dt);
+          return $dt->clone->truncate(to => $_[1]);
+        }
+        else
+        {
+          Carp::croak "Invalid argument(s) to $name: @_";
+        }
+      }
+
+      if(defined $default && !$self->{$key} && !defined $self->{$formatted_key})
+      {
+        my $dt = $db->parse_timestamp($default);
+
+        unless($dt)
+        {
+          $dt = Rose::DateTime::Util::parse_date($default, $tz || $db->server_time_zone, 1) or
+            Carp::croak "Invalid default timestamp: '$default'";
+        }
+
+        if(ref $dt)
+        {
+          $dt->set_time_zone($tz || $db->server_time_zone);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+        else
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $dt;
+        }
+      }
+
+      if($self->{STATE_SAVING()})
+      {
+        return ($self->{$key} || $self->{$formatted_key}) ? 
+          ($self->{$formatted_key} ||= $db->format_timestamp($self->{$key})) : undef;
+      }
+
+      return $self->{$key} ? $self->{$key} : 
+             $self->{$formatted_key} ? $db->parse_timestamp($self->{$formatted_key}) : undef;
+    };
+  }
+  elsif($interface eq 'set')
+  {
+    $methods{$name} = sub
+    {
+      my $self = shift;
+
+      my $db = $self->db or die "Missing Rose::DB object attribute";
+
+      Carp::croak "Missing argument in call to $name"  unless(@_);
+
+      if(defined $_[0])
+      {
+        if($self->{STATE_LOADING()})
+        {
+          $self->{$key} = undef;
+          $self->{$formatted_key} = $_[0];
+        }
+        else
+        {
+          my $dt = $db->parse_timestamp($_[0]);
+
+          unless($dt)
+          {
+            $dt = Rose::DateTime::Util::parse_date($_[0], $tz || $db->server_time_zone, 1) or
+              Carp::croak "Invalid timestamp: '$_[0]'";
+          }
+
+          $dt->set_time_zone($tz || $db->server_time_zone)  if(ref $dt);
+          $self->{$key} = $dt;
+          $self->{$formatted_key} = undef;
+        }
+      }
+      else
+      {
+        $self->{$key} = undef;
+        $self->{$formatted_key} = undef;
       }
 
       return  unless(defined wantarray);
@@ -454,7 +894,7 @@ Rose::DB::Object::MakeMethods::Date - Create date-related methods for Rose::DB::
 
 C<Rose::DB::Object::MakeMethods::Date> creates methods that deal with dates, and inherits from L<Rose::Object::MakeMethods>.  See the L<Rose::Object::MakeMethods> documentation to learn about the interface.  The method types provided by this module are described below.
 
-All method types defined by this module are designed to work with objects that are subclasses of (or otherwise conform to the interface of) L<Rose::DB::Object>.  In particular, the object is expected to have a C<db> method that returns a L<Rose::DB>-derived object.  See the L<Rose::DB::Object> documentation for more details.
+All method types defined by this module are designed to work with objects that are subclasses of (or otherwise conform to the interface of) L<Rose::DB::Object>.  In particular, the object is expected to have a L<db|Rose::DB::Object/db> method that returns a L<Rose::DB>-derived object.  See the L<Rose::DB::Object> documentation for more details.
 
 =head1 METHODS TYPES
 
@@ -481,7 +921,7 @@ attribute.  Defaults to the name of the method.
 
 =item C<interface>
 
-Choose the interface.  The only current interface is C<get_set>, which is the default.
+Choose the interface.  The default is C<get_set>.
 
 =item C<time_zone>
 
@@ -495,20 +935,20 @@ The time zone name, which must be in a format that is understood by L<DateTime::
 
 =item C<get_set>
 
-Creates a get/set accessor method for a date (year, month, day) attribute.  When setting the attribute, the value is passed through the C<parse_date()> method of the object's C<db> attribute.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
+Creates a get/set method for a date (year, month, day) attribute.  When setting the attribute, the value is passed through the C<parse_date()> method of the object's L<db|Rose::DB::Object/db> attribute.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
 
-The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the C<server_time_zone> value of the  object's C<db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
+The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the L<server_time_zone|Rose::DB/server_time_zone> value of the  object's L<db|Rose::DB::Object/db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
 
-When saving to the database, the method will pass the attribute value through the C<format_date()> method of the object's C<db> attribute before returning it.  Otherwise, the value is returned as-is.
+When saving to the database, the method will pass the attribute value through the L<format_date|Rose::DateTime::Util/format_date> method of the object's L<db|Rose::DB::Object/db> attribute before returning it.  Otherwise, the value is returned as-is.
 
-This method is designed to allow date values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_date()> method of the object's C<db> attribute.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
+This method is designed to allow date values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_date()> method of the object's L<db|Rose::DB::Object/db> attribute.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
 
-If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s C<format_date()> function along with the current value of the date attribute.  Example:
+If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s L<format_date|Rose::DateTime::Util/format_date> function along with the current value of the date attribute.  Example:
 
     $o->start_date('2004-05-22');
     print $o->start_date(format => '%A'); # "Saturday"
 
-If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s C<truncate()> method, which is applied to a clone of the current value of the date attribute, which is then returned.  Example:
+If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s L<truncate|DateTime/truncate> method, which is applied to a clone of the current value of the date attribute, which is then returned.  Example:
 
     $o->start_date('2004-05-22');
 
@@ -516,10 +956,18 @@ If passed two arguments and the first argument is "truncate", then the second ar
     # $d = $o->start_date->clone->truncate(to => 'month')
     $d = $o->start_date(truncate => 'month');
 
-If the date attribute is undefined, then undef is returned (i.e., no clone or call to C<truncate()> is made).
+If the date attribute is undefined, then undef is returned (i.e., no clone or call to L<truncate|DateTime/truncate> is made).
 
 If a valid date keyword is passed as an argument, the value will never be "inflated" but rather passed to the database I<and> returned to other code unmodified.  That means that the "truncate" and "format" calls described above will also return the date keyword unmodified.  See the L<Rose::DB> documentation for more information on date keywords.
 
+=item C<get>
+
+Creates an accessor method for a date (year, month, day) attribute.  This method behaves like the C<get_set> method, except that the value cannot be set. 
+
+=item C<set>
+
+Creates a mutator method for a date (year, month, day) attribute.  This method behaves like the C<get_set> method, except that a fatal error will occur if no arguments are passed.  It also does not support the C<truncate> and C<format> options.
+
 =back
 
 =back
@@ -567,7 +1015,7 @@ attribute.  Defaults to the name of the method.
 
 =item C<interface>
 
-Choose the interface.  The only current interface is C<get_set>, which is the default.
+Choose the interface.  The default is C<get_set>.
 
 =item C<time_zone>
 
@@ -575,9 +1023,9 @@ The time zone name, which must be in a format that is understood by L<DateTime::
 
 =item C<type>
 
-The datetime variant as a string.  Each space in the string is replaced with an underscore "_", then the string is appended to "format_" and "parse_" in order to form the names of the methods called on the object's C<db> attribute to format and parse datetime values.  The default is "datetime", which means that the C<format_datetime()> and C<parse_datetime()> methods will be used.
+The datetime variant as a string.  Each space in the string is replaced with an underscore "_", then the string is appended to "format_" and "parse_" in order to form the names of the methods called on the object's L<db|Rose::DB::Object/db> attribute to format and parse datetime values.  The default is "datetime", which means that the C<format_datetime()> and C<parse_datetime()> methods will be used.
 
-Any string that results in a set of method names that are supported by the object's C<db> attribute is acceptable.  Check the documentation for the class of the object's C<db> attribute for a list of valid method names.
+Any string that results in a set of method names that are supported by the object's L<db|Rose::DB::Object/db> attribute is acceptable.  Check the documentation for the class of the object's L<db|Rose::DB::Object/db> attribute for a list of valid method names.
 
 =back
 
@@ -587,22 +1035,22 @@ Any string that results in a set of method names that are supported by the objec
 
 =item C<get_set>
 
-Creates a get/set accessor method for a "datetime" attribute.  The exact granularity of the "datetime" value is determined by the value of the C<type> option (see above).
+Creates a get/set method for a "datetime" attribute.  The exact granularity of the "datetime" value is determined by the value of the C<type> option (see above).
 
-When setting the attribute, the value is passed through the C<parse_TYPE()> method of the object's C<db> attribute, where C<TYPE> is the value of the C<type> option.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
+When setting the attribute, the value is passed through the C<parse_TYPE()> method of the object's L<db|Rose::DB::Object/db> attribute, where C<TYPE> is the value of the C<type> option.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
 
-The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the C<server_time_zone> value of the  object's C<db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
+The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the L<server_time_zone|Rose::DB/server_time_zone> value of the  object's L<db|Rose::DB::Object/db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
 
-When saving to the database, the method will pass the attribute value through the C<format_TYPE()> method of the object's C<db> attribute before returning it, where C<TYPE> is the value of the C<type> option.  Otherwise, the value is returned as-is.
+When saving to the database, the method will pass the attribute value through the C<format_TYPE()> method of the object's L<db|Rose::DB::Object/db> attribute before returning it, where C<TYPE> is the value of the C<type> option.  Otherwise, the value is returned as-is.
 
-This method is designed to allow datetime values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_TYPE()> method of the object's C<db> attribute, where C<TYPE> is the value of the C<type> option.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
+This method is designed to allow datetime values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_TYPE()> method of the object's L<db|Rose::DB::Object/db> attribute, where C<TYPE> is the value of the C<type> option.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
 
-If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s C<format_datetime()> function along with the current value of the datetime attribute.  Example:
+If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s L<format_date|Rose::DateTime::Util/format_date> function along with the current value of the datetime attribute.  Example:
 
     $o->start_date('2004-05-22 12:34:56');
     print $o->start_date(format => '%A'); # "Saturday"
 
-If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s C<truncate()> method, which is applied to a clone of the current value of the datetime attribute, which is then returned.  Example:
+If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s L<truncate|DateTime/truncate> method, which is applied to a clone of the current value of the datetime attribute, which is then returned.  Example:
 
     $o->start_date('2004-05-22 04:32:01');
 
@@ -610,10 +1058,18 @@ If passed two arguments and the first argument is "truncate", then the second ar
     # $d = $o->start_date->clone->truncate(to => 'month')
     $d = $o->start_date(truncate => 'month');
 
-If the datetime attribute is undefined, then undef is returned (i.e., no clone or call to C<truncate()> is made).
+If the datetime attribute is undefined, then undef is returned (i.e., no clone or call to L<truncate|DateTime/truncate> is made).
 
 If a valid datetime keyword is passed as an argument, the value will never be "inflated" but rather passed to the database I<and> returned to other code unmodified.  That means that the "truncate" and "format" calls described above will also return the datetime keyword unmodified.  See the L<Rose::DB> documentation for more information on datetime keywords.
 
+=item C<get>
+
+Creates an accessor method for a "datetime" attribute.  This method behaves like the C<get_set> method, except that the value cannot be set. 
+
+=item C<set>
+
+Creates a mutator method for a "datetime" attribute.  This method behaves like the C<get_set> method, except that a fatal error will occur if no arguments are passed.  It also does not support the C<truncate> and C<format> options.
+
 =back
 
 =back
@@ -668,7 +1124,7 @@ attribute.  Defaults to the name of the method.
 
 =item C<interface>
 
-Choose the interface.  The only current interface is C<get_set>, which is the default.
+Choose the interface.  The default interface is C<get_set>.
 
 =item C<time_zone>
 
@@ -682,20 +1138,20 @@ The time zone name, which must be in a format that is understood by L<DateTime::
 
 =item C<get_set>
 
-Creates a get/set accessor method for a "timestamp" (year, month, day, hour, minute, second, fractional seconds) attribute.  When setting the attribute, the value is passed through the C<parse_timestamp()> method of the object's C<db> attribute.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
+Creates a get/set method for a "timestamp" (year, month, day, hour, minute, second, fractional seconds) attribute.  When setting the attribute, the value is passed through the C<parse_timestamp()> method of the object's L<db|Rose::DB::Object/db> attribute.  If that fails, the value is passed to L<Rose::DateTime::Util>'s C<parse_date()> function.  If that fails, a fatal error will occur.
 
-The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the C<server_time_zone> value of the  object's C<db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
+The time zone of the L<DateTime> object that results from a successful parse is set to the value of the C<time_zone> option, if defined.  Otherwise, it is set to the L<server_time_zone|Rose::DB/server_time_zone> value of the  object's L<db|Rose::DB::Object/db> attribute using L<DateTime>'s L<set_time_zone|DateTime/set_time_zone> method.
 
-When saving to the database, the method will pass the attribute value through the C<format_timestamp()> method of the object's C<db> attribute before returning it.  Otherwise, the value is returned as-is.
+When saving to the database, the method will pass the attribute value through the L<format_date|Rose::DateTime::Util/format_date> method of the object's L<db|Rose::DB::Object/db> attribute before returning it.  Otherwise, the value is returned as-is.
 
-This method is designed to allow timestamp values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_timestamp()> method of the object's C<db> attribute.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
+This method is designed to allow timestamp values to make a round trip from and back into the database without ever being "inflated" into L<DateTime> objects.  Any use of the attribute (get or set) outside the context of loading from or saving to the database will cause the value to be "inflated" using the  C<parse_timestamp()> method of the object's L<db|Rose::DB::Object/db> attribute.  If that fails, L<Rose::DateTime::Util>'s C<parse_date()> function is tried.  If that fails, a fatal error will occur.
 
-If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s C<format_timestamp()> function along with the current value of the timestamp attribute.  Example:
+If passed two arguments and the first argument is "format", then the second argument is taken as a format string and passed to L<Rose::DateTime::Util>'s L<format_date|Rose::DateTime::Util/format_date> function along with the current value of the timestamp attribute.  Example:
 
     $o->start_date('2004-05-22 12:34:56.123');
     print $o->start_date(format => '%A'); # "Saturday"
 
-If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s C<truncate()> method, which is applied to a clone of the current value of the timestamp attribute, which is then returned.  Example:
+If passed two arguments and the first argument is "truncate", then the second argument is taken as the value of the C<to> argument to L<DateTime>'s L<truncate|DateTime/truncate> method, which is applied to a clone of the current value of the timestamp attribute, which is then returned.  Example:
 
     $o->start_date('2004-05-22 04:32:01.456');
 
@@ -703,10 +1159,18 @@ If passed two arguments and the first argument is "truncate", then the second ar
     # $d = $o->start_date->clone->truncate(to => 'month')
     $d = $o->start_date(truncate => 'month');
 
-If the timestamp attribute is undefined, then undef is returned (i.e., no clone or call to C<truncate()> is made).
+If the timestamp attribute is undefined, then undef is returned (i.e., no clone or call to L<truncate|DateTime/truncate> is made).
 
 If a valid timestamp keyword is passed as an argument, the value will never be "inflated" but rather passed to the database I<and> returned to other code unmodified.  That means that the "truncate" and "format" calls described above will also return the timestamp keyword unmodified.  See the L<Rose::DB> documentation for more information on timestamp keywords.
 
+=item C<get>
+
+Creates an accessor method for a "timestamp" (year, month, day, hour, minute, second, fractional seconds) attribute.  This method behaves like the C<get_set> method, except that the value cannot be set. 
+
+=item C<set>
+
+Creates a mutator method for a "timestamp" (year, month, day, hour, minute, second, fractional seconds) attribute.  This method behaves like the C<get_set> method, except that a fatal error will occur if no arguments are passed.  It also does not support the C<truncate> and C<format> options.
+
 =back
 
 =back
