@@ -12,7 +12,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 
 our $VERSION = '0.02';
 
-__PACKAGE__->default_auto_method_types('get');
+__PACKAGE__->default_auto_method_types('get_set');
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -45,7 +45,7 @@ Rose::Object::MakeMethods::Generic->make_methods
 
 __PACKAGE__->method_maker_info
 (
-  get =>
+  get_set =>
   {
     class => 'Rose::DB::Object::MakeMethods::Generic',
     type  => 'object_by_key',
@@ -86,6 +86,18 @@ sub method_name
   return $self->SUPER::method_name(@_);
 }
 
+sub is_ready_to_make_methods
+{
+  my($self) = shift;
+
+  if(my $fk = $self->foreign_key)
+  {
+    return $fk->is_ready_to_make_methods(@_);
+  }
+
+  return $self->SUPER::is_ready_to_make_methods(@_);
+}
+
 sub make_methods
 {
   my($self) = shift;
@@ -112,7 +124,7 @@ sub build_method_name_for_type
 {
   my($self, $type) = @_;
   
-  if($type eq 'get')
+  if($type eq 'get_set')
   {
     return $self->name;
   }
@@ -146,7 +158,7 @@ This class inherits from L<Rose::DB::Object::Metadata::Relationship>. Inherited
 
 =over 4
 
-=item C<get>
+=item C<get_set>
 
 L<Rose::DB::Object::MakeMethods::Generic>, L<object_by_key|Rose::DB::Object::MakeMethods::Generic/object_by_key>, ...
 
@@ -160,7 +172,7 @@ See the L<Rose::DB::Object::Metadata::Relationship|Rose::DB::Object::Metadata::R
 
 =item B<build_method_name_for_type TYPE>
 
-Return a method name for the relationship method type TYPE.  Returns the relationship's L<name|Rose::DB::Object::Metadata::Relationship/name> for the method type "get", undef otherwise.
+Return a method name for the relationship method type TYPE.  Returns the relationship's L<name|Rose::DB::Object::Metadata::Relationship/name> for the method type "get_set", undef otherwise.
 
 =item B<foreign_key [FK]>
 
